django-fitbit
=============
[![Build Status](https://travis-ci.org/orcasgit/django-fitbit.svg?branch=master)](https://travis-ci.org/orcasgit/django-fitbit) [![Coverage Status](https://coveralls.io/repos/orcasgit/django-fitbit/badge.png)](https://coveralls.io/r/orcasgit/django-fitbit) [![Requirements Status](https://requires.io/github/orcasgit/django-fitbit/requirements.png?branch=master)](https://requires.io/github/orcasgit/django-fitbit/requirements/?branch=master)

Django-fitbit is a Django app for integrating a user's Fitbit data into your
site.

It handles the details of getting your app authorized to access your user's
Fitbit data via the Fitbit web API.

Documentation is hosted on <http://django-fitbit.readthedocs.org>.
